@@ -1,15 +1,20 @@
-# SPDX-License-Identifier: Apache-2.0.
+# Copyright 2018-2022 contributors to the OpenLineage project
+# SPDX-License-Identifier: Apache-2.0
 
 import json
+import sys
+import logging
 from enum import Enum
 from typing import List, Dict
 
 import attr
 
+log = logging.getLogger(__name__)
+
 try:
     import numpy
 except ImportError:
-    numpy = None
+    log.warning("ImportError occurred when trying to import numpy module.")
 
 
 class Serde:
@@ -23,12 +28,12 @@ class Serde:
                 {k: cls.remove_nulls_and_enums(v) for k, v in obj.items()}.items()
             ))
         if isinstance(obj, List):
-            return list(filter(lambda x: x is not None and x != {}, [
+            return list(filter(lambda x: x is not None and (isinstance(x, dict) and x != {}), [
                 cls.remove_nulls_and_enums(v) for v in obj if v is not None
             ]))
 
         # Pandas can use numpy.int64 object
-        if numpy and isinstance(obj, numpy.int64):
+        if 'numpy' in sys.modules and isinstance(obj, numpy.int64):
             return int(obj)
         return obj
 
